[Asterisk-cvs] asterisk/include/asterisk module.h,1.16,1.17

kpfleming at lists.digium.com kpfleming at lists.digium.com
Mon Jun 6 14:29:03 CDT 2005


Update of /usr/cvsroot/asterisk/include/asterisk
In directory mongoose.digium.com:/tmp/cvs-serv9837/include/asterisk

Modified Files:
	module.h 
Log Message:
add support for per-module version numbers


Index: module.h
===================================================================
RCS file: /usr/cvsroot/asterisk/include/asterisk/module.h,v
retrieving revision 1.16
retrieving revision 1.17
diff -u -d -r1.16 -r1.17
--- module.h	16 Jan 2005 22:59:30 -0000	1.16
+++ module.h	6 Jun 2005 18:31:29 -0000	1.17
@@ -66,6 +66,8 @@
  */
 int reload(void);		/*! reload configs */
 
+const char *version(void);
+
 #define ASTERISK_GPL_KEY \
 	"This paragraph is Copyright (C) 2000, Linux Support Services, Inc.  \
 In order for your module to load, it must return this key via a function \
@@ -112,9 +114,10 @@
 /*!
  * \param modentry a callback to an updater function
  * For each of the modules loaded, modentry will be executed with the resource, description,
  * and usecount values of each particular module.
  */
-int ast_update_module_list(int (*modentry)(char *module, char *description, int usecnt, char *like), char *like);
+int ast_update_module_list(int (*modentry)(const char *module, const char *description, int usecnt, const char *version, const char *like),
+			   const char *like);
 
 /*! Ask this procedure to be run with modules have been updated */
 /*!
@@ -112,9 +114,10 @@
  * \param modentry a callback to an updater function
  * For each of the modules loaded, modentry will be executed with the resource, description,
- * and usecount values of each particular module.
+ * version, and usecount values of each particular module.
  */




More information about the svn-commits mailing list